@@ -1,3 +1,4 @@
+# frozen_string_literal: true
 ##
 # This class encapsulates an HTML page.  If Mechanize finds a content
 # type of 'text/html', this class will be instantiated and returned.
@@ -103,9 +104,9 @@ class Mechanize::Page < Mechanize::File
     parser = self.parser unless parser
     return false if parser.errors.empty?
     parser.errors.any? do |error|
-      error.message =~ /(indicate\ encoding)|
-                        (Invalid\ char)|
-                        (input\ conversion\ failed)/x
+      error.message.scrub =~ /(indicate\ encoding)|
+                              (Invalid\ char)|
+                              (input\ conversion\ failed)/x
     end
   end
 
