@@ -25,6 +25,14 @@ class TestMechanizeHttpAuthChallenge < Mechanize::TestCase
     assert_equal expected, @challenge.realm(@uri + '/foo')
   end
 
+  def test_realm_digest_case
+    challenge = @AC.new 'Digest', { 'realm' => 'R' }, 'Digest realm=R'
+
+    expected = @AR.new 'Digest', @uri, 'R'
+
+    assert_equal expected, challenge.realm(@uri + '/foo')
+  end
+
   def test_realm_unknown
     @challenge.scheme = 'Unknown'
 
@@ -39,6 +47,12 @@ class TestMechanizeHttpAuthChallenge < Mechanize::TestCase
     assert_equal 'r', @challenge.realm_name
   end
 
+  def test_realm_name_case
+    challenge = @AC.new 'Digest', { 'realm' => 'R' }, 'Digest realm=R'
+
+    assert_equal 'R', challenge.realm_name
+  end
+
   def test_realm_name_ntlm
     challenge = @AC.new 'Negotiate, NTLM'
 
